@@ -1,7 +1,7 @@
 package Bible::OBML;
 # ABSTRACT: Open Bible Markup Language parser and renderer
 
-use 5.030;
+use 5.020;
 
 use exact;
 use exact::class;
@@ -10,7 +10,7 @@ use Mojo::Util 'html_unescape';
 use Text::Wrap 'wrap';
 use Bible::Reference;
 
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.03'; # VERSION
 
 has _load             => {};
 has indent_width      => 4;
@@ -207,7 +207,10 @@ sub _obml_to_clean_html ( $self, $obml ) {
     $obml =~ s|(\S)(?=\n\S)|$1<br>|g;
 
     $obml =~ s`(?:^|(?<=\n\n))(?!<(?:reference|sub_header|header)\b)`<p>`g;
-    $obml =~ s`(?<!</(?:reference|sub_header|header)>)(?:$|(?=\n\n))`</p>`g;
+    $obml =~ s`(?:$|(?=\n\n))`</p>`g;
+    $obml =~ s`(?<=</reference>)</p>``g;
+    $obml =~ s`(?<=</sub_header>)</p>``g;
+    $obml =~ s`(?<=</header>)</p>``g;
 
     $obml =~ s!\|(\d+)\|\s*!<verse_number>$1</verse_number>!g;
 
@@ -333,7 +336,7 @@ Bible::OBML - Open Bible Markup Language parser and renderer
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =for markdown [![test](https://github.com/gryphonshafer/Bible-OBML/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bible-OBML/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Bible-OBML/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bible-OBML)
@@ -348,6 +351,7 @@ version 2.02
     use Bible::OBML;
     my $bo = Bible::OBML->new;
 
+    use Bible::OBML::Gateway;
     my $gw   = Bible::OBML::Gateway->new;
     my $html = $gw->parse( $gw->fetch( 'Romans 12', 'NIV' ) );
 
@@ -578,7 +582,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2021 by Gryphon Shafer.
+This software is Copyright (c) 2014-2050 by Gryphon Shafer.
 
 This is free software, licensed under:
 
